tests: avoid failure when running with no tty
[debian/gzip] / zip.c
diff --git a/zip.c b/zip.c
index a3b4559fdd5febe1d0825f9f26e28b8cdbc2ab7e..eb5661ff85e0806fbd8b087ebd07290938c37c0e 100644 (file)
--- a/zip.c
+++ b/zip.c
@@ -1,6 +1,6 @@
 /* zip.c -- compress files to the gzip or pkzip format
 
-   Copyright (C) 1997-1999, 2006-2007, 2009-2016 Free Software Foundation, Inc.
+   Copyright (C) 1997-1999, 2006-2007, 2009-2017 Free Software Foundation, Inc.
    Copyright (C) 1992-1993 Jean-loup Gailly
 
    This program is free software; you can redistribute it and/or modify
@@ -60,9 +60,9 @@ int zip(in, out)
       stamp = time_stamp.tv_sec;
     else
       {
/* It's intended that time stamp 0 generates this warning,
            since gzip format reserves 0 for something else.  */
-        warning ("file time stamp out of range for gzip format");
+        warning ("file timestamp out of range for gzip format");
         stamp = 0;
       }
     put_long (stamp);
@@ -60,9 +60,9 @@ int zip(in, out)
     else
       {
-        /* It's intended that time stamp 0 generates this warning,
+        /* It's intended that timestamp 0 generates this warning,
            since gzip format reserves 0 for something else.  */